==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicMenuItemUI__24MenuDragMouseHandler.h <==
// public class javax.swing.plaf.basic.BasicMenuItemUI$MenuDragMouseHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 589fbf3074d3bf0a javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler_H_
#define _JC_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_MenuDragMouseEvent$object;
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$refs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vmethods	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtable	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtype	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method$_init$3de4006e6037e987(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method$menuDragMouseDragged$4e03b0ba19de0bc3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method$menuDragMouseEntered$922648d6048c1896(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method$menuDragMouseExited$a946eec552e830a2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method$menuDragMouseReleased$3ebe79196c3952be(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method_info$menuDragMouseDragged$4e03b0ba19de0bc3;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method_info$menuDragMouseEntered$922648d6048c1896;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method_info$menuDragMouseExited$a946eec552e830a2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method_info$menuDragMouseReleased$3ebe79196c3952be;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vmethods {
	void	(*menuDragMouseDragged$4e03b0ba19de0bc3)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);
	void	(*menuDragMouseEntered$922648d6048c1896)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);
	void	(*menuDragMouseExited$a946eec552e830a2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);
	void	(*menuDragMouseReleased$3ebe79196c3952be)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vmethods	javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicMenuItemUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$refs {
    _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_refs	javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_nonrefs	javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object {
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtype _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicMenuItemUI__24MenuDragMouseHandler.h <==
// public class javax.swing.plaf.basic.BasicMenuItemUI$MenuDragMouseHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 60aa650b463aab8a javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler_H_
#define _JC_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_MenuDragMouseEvent$object;
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$refs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vmethods	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtable	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtype	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method$_init$3de4006e6037e987(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method$menuDragMouseDragged$4e03b0ba19de0bc3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method$menuDragMouseEntered$922648d6048c1896(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method$menuDragMouseExited$a946eec552e830a2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method$menuDragMouseReleased$3ebe79196c3952be(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method_info$menuDragMouseDragged$4e03b0ba19de0bc3;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method_info$menuDragMouseEntered$922648d6048c1896;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method_info$menuDragMouseExited$a946eec552e830a2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$method_info$menuDragMouseReleased$3ebe79196c3952be;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vmethods {
	void	(*menuDragMouseDragged$4e03b0ba19de0bc3)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;
	void	(*menuDragMouseEntered$922648d6048c1896)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;
	void	(*menuDragMouseExited$a946eec552e830a2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;
	void	(*menuDragMouseReleased$3ebe79196c3952be)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object *, struct _jc_javax_swing_event_MenuDragMouseEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vmethods	javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicMenuItemUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$refs {
    _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_refs	javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$sub_nonrefs	javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$object {
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$vtype _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicMenuItemUI__24MenuDragMouseHandler_H_ */
